@@ -39,7 +39,7 @@ get '/ajax/content/report/apradiochannelpower/data' => require_login sub {
 get '/ajax/content/report/apradiochannelpower' => require_login sub {
 
     if ( request->is_ajax ) {
-        template 'ajax/report/apradiochannelpower.tt', {}, { layout => undef };
+        template 'ajax/report/apradiochannelpower.tt', {}, { layout => 'noop' };
     }
     else {
         my @results
@@ -50,7 +50,7 @@ get '/ajax/content/report/apradiochannelpower' => require_login sub {
 
         header( 'Content-Type' => 'text/comma-separated-values' );
         template 'ajax/report/apradiochannelpower_csv.tt',
-            { results => \@results, }, { layout => undef };
+            { results => \@results, }, { layout => 'noop' };
     }
 };
 
